@@ -26,7 +26,7 @@ class ApiService:
 
         with open(target_dir) as json_file:
             self.__constant = json.load(json_file)
-        self.options = UM.UserModel(self.apiKey, self.apiSecret)
+        self.options = UM(self.apiKey, self.apiSecret)
 
     def testConnectivity(self):
         """
@@ -108,21 +108,22 @@ class ApiService:
         :returns: (json) Return requested value from api.
         """
         try:
+            timestamp = self.testConnectivity()["timestamp"]
             params = {"symbol": symbol, "limit": str(limit)}
             start_ts = None
             end_ts = None
 
-            if startDate:
-                start_ts = date_to_milliseconds(startDate)
-            end_ts = None
-            if endDate:
-                end_ts = date_to_milliseconds(endDate)
-
-            if start_ts and end_ts:
-                params["startTime"] = start_ts
-                params["endTime"] = end_ts
-
-            result = sendRequestWithoutAuthorization("/trades", params)
+            # if startDate:
+            #     start_ts = date_to_milliseconds(startDate)
+            # end_ts = None
+            # if endDate:
+            #     end_ts = date_to_milliseconds(endDate)
+            #
+            # if start_ts and end_ts:
+            params["startTime"] = startDate
+            params["endTime"] = endDate
+            print(params)
+            result = sendRequestWithoutAuthorization("/aggTrades", params)
             return result.json()
 
         except Exception:
@@ -130,7 +131,7 @@ class ApiService:
             errorDetails = "".join(traceback.format_exception(exc_type, exc_obj, exc_tb))
             print(errorDetails)
 
-    def getKline(self, symbol, interval, startDate, endDate, limit=500):
+    def getKline(self, symbol, interval, startDate=None, endDate=None, limit=500):
         """
         Get market data of given parity from market in given dates.
 
@@ -145,16 +146,16 @@ class ApiService:
             params = {"symbol": symbol, "limit": str(limit), "interval": interval}
             start_ts = None
             end_ts = None
-
-            if startDate:
-                start_ts = date_to_milliseconds(startDate)
-            end_ts = None
-            if endDate:
-                end_ts = date_to_milliseconds(endDate)
-
-            if start_ts and end_ts:
-                params["startTime"] = start_ts
-                params["endTime"] = end_ts
+            #
+            # if startDate:
+            #     start_ts = date_to_milliseconds(startDate)
+            # end_ts = None
+            # if endDate:
+            #     end_ts = date_to_milliseconds(endDate)
+            #
+            if endDate and startDate:
+                params["startTime"] = startDate
+                params["endTime"] = endDate
             result = sendRequestWithoutAuthorization("/klines", params)
             return result.json()
 
@@ -389,8 +390,8 @@ class ApiService:
         :returns: (json) Return requested value from api.
         """
         try:
-            params = {"orderID": orderID}
-            result = sendRequest("GET", "/open/v1/orders/cancel", self.options, params)
+            params = {"orderId": str(orderID)}
+            result = sendRequest("POST", "/open/v1/orders/cancel", self.options, params)
             return result
 
         except Exception:
